<?php
namespace Service;

use Doctrine\ORM\EntityManager;
use \Util\Utilities;

/**
 * Class StructureType
 *
 * @package Service
 */
class StructureType {

	/** @var EntityManager $entityManager */
	protected $entityManager;
    protected $structureTypeFactory;
	protected $environment;

    const ORGANIZATION_LABEL =      'Organização';
    const ORGANIZATION_CONTROL =    'C';
    const BUSINESS_LABEL =          'Empresa';
    const BUSINESS_CONTROL =        'B';
    const TEAM_LABEL =              'Equipe';
    const TEAM_CONTROL =            'T';

	public function __construct(EntityManager $entityManager, \Util\Utilities $environment,
                                \Factory\StructureType $structureTypeFactory) {
		$this->entityManager = $entityManager;
        $this->structureTypeFactory = $structureTypeFactory;
		$this->environment = $environment;
	}

	public function createStructureType($label, $control = null){
        $entity = $this->entityManager->getRepository('\Zeedhi\DevOps\Model\Projectmanagement\Entities\StructureType')
            ->findOneBy(array("label" => $label, "organization" => $this->environment->getCurrentOrganizationId()));
        if(empty($entity)) {
            $entity = $this->structureTypeFactory->create($label, $control);
            $this->entityManager->persist($entity);
            $this->entityManager->flush();
        }else {
            throw new \Exception('já existe um tipo de estrutura com esse rótulo nessa mesma organização.',1);
        }
        return $entity;
    }
    public function checkStructureTypeInUser($structureTypeId){
        /** @var \Zeedhi\DevOps\Model\Projectmanagement\Entities\Structure[] $structures */
        $structures = $this->entityManager->getRepository('\Zeedhi\DevOps\Model\Projectmanagement\Entities\Structure')->
                    findBy(array('structureType' =>$structureTypeId));
        if(empty($structures)){
            $return = false;
        }else{
            $names = '';
            foreach ($structures as $structure){
                $names .=  $structure->getName().', ';
            }
            $return = 'Tipo sendo usado na(s) estrutura(s) '.substr($names, 0, -2);
        }
        return $return;
    }

} 